function [PIx,c,r] = iqcint(PI,x)
% function [PIx,c,r] = iqcint(PI,x)
%
% This function forms the combination of IQC multipliers
%   PIx = x(1)*PI(:,:,1) + ... + x(N)*PI(:,:,N)
% It returns PIx as well as the center/radius asscoiated with the circle
% constraint defined by PIx.
%
% Inputs:
%   -PI: 2-by-2-by-N complex matrix with PI(2,2)<0
%   -x: N-by-1 real vector with x(i)>=0 for all i and x(j)>0 for at least
%         one j. This is an optional input [Default is x=1].
%
% Outputs:
%   -PIx: 2-by-2 conic combination x(1)*PI(:,:,1) + ... + x(N)*PI(:,:,N)
%   -c: Scalar complex number that gives the center of the IQC circle.
%   -r: Scalar real number that gives the radius of the IQC circle.

% 12/19/2013 PJS Update for single QC

% XXX Add error checking

% Default value for x
if nargin==1
    x=1;
end

% Form combined IQC
N = numel(x);
PIx = zeros(2);
for i=1:N
    PIx = PIx + x(i)*PI(:,:,i);
end

% Determine radius and center
scl = abs(PIx(2,2));
PIscl = PIx/scl;
c = PIscl(2,1);
r = sqrt( PIscl(1,1) + abs(c)^2 );


    